darkhistory.physics.struct_boost_func — DarkHistory documentation

# darkhistory.physics.struct_boost_func

`darkhistory.physics.` `struct_boost_func`(model='einasto_with_subs', model_params=None)

  Structure formation boost factor 1+B(z).

  Parameters: | model : {‘einasto_with_subs’, ‘erfc’} Model to use. See 1604.02457. model_params : tuple of floats Model parameters (b_h, delta, z_h) for ‘erfc’ option.
  Returns: | float or ndarray Boost factor.

  Notes

  Refer to 1408.1109 for erfc model, 1604.02457 for all other model descriptions and parameters.

#### Previous topic

darkhistory.physics.inj_rate

#### Next topic

darkhistory.physics.rydberg

### This Page

Show Source